function [s_e, mErr, stdErr] = quantErrModeled(gain)
    %Models quantization error of mean and std dev of poisson distribution
    %for signal from 0.1 to maxe e-. Works with gain of 1.0 DN/e- or less only
    maxe = 64;
    maxDN = (maxe + 6*sqrt(maxe))*gain; %DN, no need to go over 6 sigma
    DN = 0:maxDN;
    s_e(1) =0.1;
    i=1;
    while s_e(i) <= maxe                                %e-, signal under evaluation
        weight = weightInLevels(s_e(i), gain, maxDN);   %find 'count' in each 'bin'
        m_DN(i) = sum(DN.*weight);                      %DN, measured mean
        std_DN(i) = sqrt(sum(weight.*(DN-m_DN(i)).^2)); %measured stdev
        s_e(i+1) = s_e(i) * 2^(1/4);                    %e-, 4 measurements per stop
        i=i+1;
    end
    s_e = s_e(1:end-1);                 %e-, one too many s_e in loop above
    stdErr = std_DN./gain./sqrt(s_e);   %error in signal standard dev
    mErr = m_DN./gain./s_e;             %error in mean
end