function weight = weightInLevels(lambda, gain, maxDN)
    %Determines the fraction (or weight) of e- in DN from 0 to max DN
    %Given poisson distributed signal lambda in e- and gain in DN/e-
    if gain > 1
        error('Gain needs to be 1 or less')
    end
    weight = zeros(1,floor(maxDN)+1);
    for DN = 0:maxDN     %DNs to estimate e- count for
        if DN > 0
            lowEdge = hiEdge + 1;
            hiEdge = ceil(1/gain*(DN+0.5))-1;
        else
            lowEdge = 0;
            hiEdge = ceil(1/gain/2)-1;
        end
        %display(['DN ' num2str(DN) ', lower ' num2str(lower) ', upper ' num2str(upper)])
        i = lowEdge:hiEdge;
        weight(DN+1) = exp(-lambda)*sum(lambda.^i./factorial(i));
    end
    weight(isnan(weight)) = 0;          %purge NaNs
    weight(~isfinite(weight)) = 0;      %and Infs
    if abs(sum(weight)-1) > 0.0001
        display(['CDF sums up to ' num2str (sum(weight)) ' at lambda = ' num2str(lambda)])
    end
end